diff src/share/vm/prims/jni.cpp @ 21559:be896a1983c0

recast all Graal native code as JVMCI code (JBS:GRAAL-53)
author Doug Simon <doug.simon@oracle.com>
date Thu, 28 May 2015 15:36:48 +0200
parents 7848fc12602b
children
line wrap: on
line diff
--- a/src/share/vm/prims/jni.cpp	Wed May 27 13:43:27 2015 +0200
+++ b/src/share/vm/prims/jni.cpp	Thu May 28 15:36:48 2015 +0200
@@ -33,9 +33,9 @@
 #include "classfile/vmSymbols.hpp"
 #include "interpreter/linkResolver.hpp"
 #include "utilities/macros.hpp"
-#ifdef GRAAL
-#include "graal/graalCompiler.hpp"
-#include "graal/graalRuntime.hpp"
+#ifdef JVMCI
+#include "jvmci/jvmciCompiler.hpp"
+#include "jvmci/jvmciRuntime.hpp"
 #endif
 #if INCLUDE_ALL_GCS
 #include "gc_implementation/g1/g1SATBCardTableModRefBS.hpp"
@@ -5209,27 +5209,27 @@
     *vm = (JavaVM *)(&main_vm);
     *(JNIEnv**)penv = thread->jni_environment();
 
 #if defined(GRAAL)
     // We turn off CompileTheWorld so that compilation requests are not ignored during bootstrap or that Graal can be compiled by C1/C2.
     bool doCTW = CompileTheWorld;
     CompileTheWorld = false;
 #endif
 
-#ifdef COMPILERGRAAL
-    // Graal is initialized on a CompilerThread
-    if (FLAG_IS_DEFAULT(BootstrapGraal) ? !TieredCompilation : BootstrapGraal) {
-      GraalCompiler::instance()->bootstrap();
+#ifdef COMPILERJVMCI
+    // JVMCI is initialized on a CompilerThread
+    if (FLAG_IS_DEFAULT(BootstrapJVMCI) ? !TieredCompilation : BootstrapJVMCI) {
+      JVMCICompiler::instance()->bootstrap();
     }
-#elif defined(GRAAL)
+#elif defined(JVMCI)
     if (doCTW) {
       // required for hosted CTW.
       CompilationPolicy::completed_vm_startup();
     }
 #endif
 
-#if defined(GRAAL)
+#if defined(JVMCI)
     if (doCTW) {
-      GraalCompiler::instance()->compile_the_world();
+      JVMCICompiler::instance()->compile_the_world();
     }
 #endif
@@ -5209,27 +5209,27 @@
     *(JNIEnv**)penv = thread->jni_environment();
 
-#if defined(GRAAL)
-    // We turn off CompileTheWorld so that compilation requests are not ignored during bootstrap or that Graal can be compiled by C1/C2.
+#if defined(JVMCI)
+    // We turn off CompileTheWorld so that compilation requests are not ignored during bootstrap or that JVMCI can be compiled by C1/C2.
     bool doCTW = CompileTheWorld;
     CompileTheWorld = false;